@@ -11,10 +11,10 @@ class Factures:
         self._con = con
 
     def get_factures_imprimir(self, p_factura_id: int):
-        req = self._con.get(url=self._url_get_factures_imprimir.format(albara_id=p_factura_id))
+        req = self._con.get(url=self._url_get_factures_imprimir.format(factura_id=p_factura_id))
         return req.json()
 
-    def get_albara_llistat(self,
+    def get_factures_llistat(self,
                            exercici: int = None,
                            client_id: int = None,
                            tercer_distribucio_id: int = None,
